<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About </source>
        <translation>Despre </translation>
    </message>
    <message>
        <source>About</source>
        <translation>Despre</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versiune</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Închide</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donează</translation>
    </message>
    <message>
        <source>Contact</source>
        <translation>Contact</translation>
    </message>
</context>
<context>
    <name>AboutTab</name>
    <message>
        <source>License: </source>
        <translation>Licență: </translation>
    </message>
    <message>
        <source>Screenshot and Annotation Tool</source>
        <translation>Unealtă pentru capturi de ecran și adnotări</translation>
    </message>
</context>
<context>
    <name>ActionSettingTab</name>
    <message>
        <source>Name</source>
        <translation>Denumire</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Scurtătură</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Curăță</translation>
    </message>
    <message>
        <source>Take Capture</source>
        <translation>Fă o captură</translation>
    </message>
    <message>
        <source>Include Cursor</source>
        <translation>Include cursorul</translation>
    </message>
    <message>
        <source>Delay</source>
        <translation>Întârziere</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>s</translation>
    </message>
    <message>
        <source>Capture Mode</source>
        <translation>Regim captură</translation>
    </message>
    <message>
        <source>Show image in Pin Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy image to Clipboard</source>
        <translation>Copiază imaginea în clipboard</translation>
    </message>
    <message>
        <source>Upload image</source>
        <translation>Încarcă imaginea</translation>
    </message>
    <message>
        <source>Open image parent directory</source>
        <translation>Deschide dosarul părinte al imaginii</translation>
    </message>
    <message>
        <source>Save image</source>
        <translation>Salvează imaginea</translation>
    </message>
    <message>
        <source>Hide Main Window</source>
        <translation>Ascunde fereastra principală</translation>
    </message>
</context>
<context>
    <name>ActionsSettings</name>
    <message>
        <source>Add</source>
        <translation>Adaugă</translation>
    </message>
    <message>
        <source>Actions Settings</source>
        <translation>Configurări acțiune</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Acțiune</translation>
    </message>
</context>
<context>
    <name>AddWatermarkOperation</name>
    <message>
        <source>Watermark Image Required</source>
        <translation>Imagine-filigran necesară</translation>
    </message>
    <message>
        <source>Please add a Watermark Image via Options &gt; Settings &gt; Annotator &gt; Update</source>
        <translation>Adăugați o imagine-filigran în Opțiuni &gt; Configurări &gt; Adnotator &gt; Actualizează</translation>
    </message>
</context>
<context>
    <name>AnnotationSettings</name>
    <message>
        <source>Smooth Painter Paths</source>
        <translation>Netezește căile pictorului</translation>
    </message>
    <message>
        <source>When enabled smooths out pen and
marker paths after finished drawing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smooth Factor</source>
        <translation>Factor de netezime</translation>
    </message>
    <message>
        <source>Increasing the smooth factor will decrease
precision for pen and marker but will
make them more smooth.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Annotator Settings</source>
        <translation>Configurări adnotator</translation>
    </message>
    <message>
        <source>Remember annotation tool selection and load on startup</source>
        <translation>Ține minte selecția uneltei de adnotare și încarc-o la lansare</translation>
    </message>
    <message>
        <source>Switch to Select Tool after drawing Item</source>
        <translation>Schimbă la unealta de selecție după desenarea elementului</translation>
    </message>
    <message>
        <source>Number Tool Seed change updates all Number Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disabling this option causes changes of the number tool
seed to affect only new items but not existing items.
Disabling this option allows having duplicate numbers.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Canvas Color</source>
        <translation>Culoare canava</translation>
    </message>
    <message>
        <source>Default Canvas background color for annotation area.
Changing color affects only new annotation areas.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Item after drawing</source>
        <translation>Alege elementul după desenare</translation>
    </message>
    <message>
        <source>With this option enabled the item gets selected after
being created, allowing changing settings.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ApplicationSettings</name>
    <message>
        <source>Capture screenshot at startup with default mode</source>
        <translation>Fă o captură la pornire cu regimul implicit</translation>
    </message>
    <message>
        <source>Application Style</source>
        <translation>Stil aplicație</translation>
    </message>
    <message>
        <source>Sets the application style which defines the look and feel of the GUI.
Change requires ksnip restart to take effect.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Application Settings</source>
        <translation>Configurări aplicație</translation>
    </message>
    <message>
        <source>Automatically copy new captures to clipboard</source>
        <translation>Copiază automat noua captură în clipboard</translation>
    </message>
    <message>
        <source>Use Tabs</source>
        <translation>Folosește file</translation>
    </message>
    <message>
        <source>Change requires restart.</source>
        <translation>Schimbarea necesită repornire.</translation>
    </message>
    <message>
        <source>Run ksnip as single instance</source>
        <translation>Rulează KSnip ca instanță unică</translation>
    </message>
    <message>
        <source>Hide Tabbar when only one Tab is used.</source>
        <translation>Ascunde bara de file când e folosită doar o filă.</translation>
    </message>
    <message>
        <source>Enabling this option will allow only one ksnip instance to run,
all other instances started after the first will pass its
arguments to the first and close. Changing this option requires
a new start of all instances.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remember Main Window position on move and load on startup</source>
        <translation>Ține minte poziția ferestrei principale la mutare și încarc-o la lansare</translation>
    </message>
    <message>
        <source>Auto hide Tabs</source>
        <translation>Ascunde filele automat</translation>
    </message>
    <message>
        <source>Auto hide Docks</source>
        <translation>Ascunde andocările automat</translation>
    </message>
    <message>
        <source>On startup hide Toolbar and Annotation Settings.
Docks visibility can be toggled with the Tab Key.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto resize to content</source>
        <translation>Redimensionează automat la conținut</translation>
    </message>
    <message>
        <source>Automatically resize Main Window to fit content image.</source>
        <translation>Redimensionează automat fereastra principală să se potrivească cu conținutul.</translation>
    </message>
    <message>
        <source>Enable Debugging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enables debug output written to the console.
Change requires ksnip restart to take effect.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resize to content delay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resizing to content is delay to allow the Window Manager to receive
the new content. In case that the Main Windows is not adjusted correctly
to the new content, increasing this delay might improve the behavior.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AuthorTab</name>
    <message>
        <source>Contributors:</source>
        <translation>Contribuitori:</translation>
    </message>
    <message>
        <source>Spanish Translation</source>
        <translation>Traducere spaniolă</translation>
    </message>
    <message>
        <source>Dutch Translation</source>
        <translation>Traducere olandeză</translation>
    </message>
    <message>
        <source>Russian Translation</source>
        <translation>Traducere rusă</translation>
    </message>
    <message>
        <source>Norwegian Bokmål Translation</source>
        <translation>Traducere norvegiană Bokmål</translation>
    </message>
    <message>
        <source>French Translation</source>
        <translation>Traducere franceză</translation>
    </message>
    <message>
        <source>Polish Translation</source>
        <translation>Traducere poloneză</translation>
    </message>
    <message>
        <source>Snap &amp; Flatpak Support</source>
        <translation>Suport pentru Snap și Flatpak</translation>
    </message>
    <message>
        <source>The Authors:</source>
        <translation>Autorii:</translation>
    </message>
</context>
<context>
    <name>CanDiscardOperation</name>
    <message>
        <source>Warning - </source>
        <translation>Avertisment – </translation>
    </message>
    <message>
        <source>The capture %1%2%3 has been modified.
Do you want to save it?</source>
        <translation>Captura %1%2%3 a fost modificată.
Doriți să o salvați?</translation>
    </message>
</context>
<context>
    <name>CaptureModePicker</name>
    <message>
        <source>New</source>
        <translation>Nou</translation>
    </message>
    <message>
        <source>Draw a rectangular area with your mouse</source>
        <translation>Desenați o zonă dreptunghiulară cu mausul</translation>
    </message>
    <message>
        <source>Capture full screen including all monitors</source>
        <translation>Capturează ecran complet incluzând toate monitoarele</translation>
    </message>
    <message>
        <source>Capture screen where the mouse is located</source>
        <translation>Capturează ecranul pe care e mausul</translation>
    </message>
    <message>
        <source>Capture window that currently has focus</source>
        <translation>Capturează fereastra care e focalizată acum</translation>
    </message>
    <message>
        <source>Capture that is currently under the mouse cursor</source>
        <translation>Capturează ce e acum sub cursorul mausului</translation>
    </message>
    <message>
        <source>Capture a screenshot of the last selected rectangular area</source>
        <translation>Fă o captură a ultimei zone dreptunghiulare alese</translation>
    </message>
    <message>
        <source>Uses the screenshot Portal for taking screenshot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ContactTab</name>
    <message>
        <source>Community</source>
        <translation>Comunitate</translation>
    </message>
    <message>
        <source>Bug Reports</source>
        <translation>Rapoarte de defecte</translation>
    </message>
    <message>
        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please use %1 to report bugs.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CopyAsDataUriOperation</name>
    <message>
        <source>Failed to copy to clipboard</source>
        <translation>Copierea în clipboard a eșuat</translation>
    </message>
    <message>
        <source>Failed to copy to clipboard as base64 encoded image.</source>
        <translation>Copierea în clipboard ca imagine codată cu base64 a eșuat.</translation>
    </message>
    <message>
        <source>Copied to clipboard</source>
        <translation>Copiat în clipboard</translation>
    </message>
    <message>
        <source>Copied to clipboard as base64 encoded image.</source>
        <translation>Copiat în clipboard ca imagine codată cu base64.</translation>
    </message>
</context>
<context>
    <name>DeleteImageOperation</name>
    <message>
        <source>Delete Image</source>
        <translation>Șterge imaginea</translation>
    </message>
    <message>
        <source>The item &apos;%1&apos; will be deleted.
Do you want to continue?</source>
        <translation>Elementul „%1” va fi șters.
Doriți să continuați?</translation>
    </message>
</context>
<context>
    <name>DonateTab</name>
    <message>
        <source>Donations are always welcome</source>
        <translation>Donațiile sunt binevenite mereu</translation>
    </message>
    <message>
        <source>Donation</source>
        <translation>Donație</translation>
    </message>
    <message>
        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Become a GitHub Sponsor?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Also possible, %1here%2.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EmptyActionSettingTab</name>
    <message>
        <source>Add new actions by pressing the &apos;Add&apos; tab button.</source>
        <translation>Adăugați acțiuni noi apăsând pe butonul „Adaugă” de pe filă.</translation>
    </message>
</context>
<context>
    <name>EnumTranslator</name>
    <message>
        <source>Rectangular Area</source>
        <translation>Zonă dreptunghiulară</translation>
    </message>
    <message>
        <source>Last Rectangular Area</source>
        <translation>Ultima zonă dreptunghiulară</translation>
    </message>
    <message>
        <source>Full Screen (All Monitors)</source>
        <translation>Ecran complet (toate monitoarele)</translation>
    </message>
    <message>
        <source>Current Screen</source>
        <translation>Ecranul actual</translation>
    </message>
    <message>
        <source>Active Window</source>
        <translation>Fereastra activă</translation>
    </message>
    <message>
        <source>Window Under Cursor</source>
        <translation>Fereastra de sub cursor</translation>
    </message>
    <message>
        <source>Screenshot Portal</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FtpUploaderSettings</name>
    <message>
        <source>Force anonymous upload.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Url</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished">Utilizator</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HandleUploadResultOperation</name>
    <message>
        <source>Upload Successful</source>
        <translation>Încărcare reușită</translation>
    </message>
    <message>
        <source>Unable to save temporary image for upload.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to start process, check path and permissions.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Process crashed</source>
        <translation>Procesul a eșuat</translation>
    </message>
    <message>
        <source>Process timed out.</source>
        <translation>Procesul a expirat.</translation>
    </message>
    <message>
        <source>Process read error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Process write error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Web error, check console output.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upload Failed</source>
        <translation>Încărcarea a eșuat</translation>
    </message>
    <message>
        <source>Script wrote to StdErr.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FTP Upload finished successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection Error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Permission Error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upload script %1  finished successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Uploaded to %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HotKeySettings</name>
    <message>
        <source>Enable Global HotKeys</source>
        <translation>Activează scurtături globale</translation>
    </message>
    <message>
        <source>Capture Rect Area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture Full Screen</source>
        <translation>Capturează ecran complet</translation>
    </message>
    <message>
        <source>Capture current Screen</source>
        <translation>Capturează ecranul actual</translation>
    </message>
    <message>
        <source>Capture active Window</source>
        <translation>Capturează fereastra activă</translation>
    </message>
    <message>
        <source>Capture Window under Cursor</source>
        <translation>Capturează fereastra de sub cursor</translation>
    </message>
    <message>
        <source>Global HotKeys</source>
        <translation>Scurtături globale</translation>
    </message>
    <message>
        <source>Capture Last Rect Area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Curăță</translation>
    </message>
    <message>
        <source>Capture using Portal</source>
        <translation>Capturează folosind Portalul</translation>
    </message>
    <message>
        <source>HotKeys are currently supported only for Windows and X11.
Disabling this option makes also the action shortcuts ksnip only.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImageGrabberSettings</name>
    <message>
        <source>Capture mouse cursor on screenshot</source>
        <translation>Capturează cursorul mausului</translation>
    </message>
    <message>
        <source>Should mouse cursor be visible on
screenshots.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>Acaparator de imagini</translation>
    </message>
    <message>
        <source>Generic Wayland implementations that use
XDG-DESKTOP-PORTAL handle screen scaling
differently. Enabling this option will
determine the current screen scaling and
apply that to the screenshot in ksnip.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GNOME and KDE Plasma support their own Wayland
and the Generic XDG-DESKTOP-PORTAL screenshots.
Enabling this option will force KDE Plasma and
GNOME to use the XDG-DESKTOP-PORTAL screenshots.
Change in this option require a ksnip restart.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Main Window after capturing screenshot</source>
        <translation>Arată fereastra principală după capturare</translation>
    </message>
    <message>
        <source>Hide Main Window during screenshot</source>
        <translation>Ascunde fereastra principală în timpul capturării</translation>
    </message>
    <message>
        <source>Hide Main Window when capturing a new screenshot.</source>
        <translation>Ascunde fereastra principală în timpul capturării ecranului.</translation>
    </message>
    <message>
        <source>Show Main Window after capturing a new screenshot
when the Main Window was hidden or minimize.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgurHistoryDialog</name>
    <message>
        <source>Imgur History</source>
        <translation>Istoric Imgur</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Închide</translation>
    </message>
    <message>
        <source>Time Stamp</source>
        <translation>Ștampilă temporală</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Legătură</translation>
    </message>
    <message>
        <source>Delete Link</source>
        <translation>Șterge legătura</translation>
    </message>
</context>
<context>
    <name>ImgurUploader</name>
    <message>
        <source>Upload to imgur.com finished!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Received new token, trying upload again…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Imgur token has expired, requesting new token…</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgurUploaderSettings</name>
    <message>
        <source>Force anonymous upload</source>
        <translation>Forțează încărcare anonimă</translation>
    </message>
    <message>
        <source>Always copy Imgur link to clipboard</source>
        <translation>Copiază mereu legătura Imgur în clipboard</translation>
    </message>
    <message>
        <source>Client ID</source>
        <translation>Id. client</translation>
    </message>
    <message>
        <source>Client Secret</source>
        <translation>Secret client</translation>
    </message>
    <message>
        <source>PIN</source>
        <translation>PIN</translation>
    </message>
    <message>
        <source>Enter imgur Pin which will be exchanged for a token.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Get PIN</source>
        <translation>Obține PIN-ul</translation>
    </message>
    <message>
        <source>Get Token</source>
        <translation>Obține jetonul</translation>
    </message>
    <message>
        <source>Imgur History</source>
        <translation>Istoric Imgur</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Încărcător Imgur</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Utilizator</translation>
    </message>
    <message>
        <source>Waiting for imgur.com…</source>
        <translation>Se așteaptă imgur.com…</translation>
    </message>
    <message>
        <source>Imgur.com token successfully updated.</source>
        <translation>Jeton imgur.com actualizat cu succes.</translation>
    </message>
    <message>
        <source>Imgur.com token update error.</source>
        <translation>Eroare la actualizarea jetonului imgur.com.</translation>
    </message>
    <message>
        <source>After uploading open Imgur link in default browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link directly to image</source>
        <translation>Leagă direct la imagine</translation>
    </message>
    <message>
        <source>Base Url:</source>
        <translation>URL de bază:</translation>
    </message>
    <message>
        <source>Base url that will be used for communication with Imgur.
Changing requires restart.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear Token</source>
        <translation>Curăță jetonul</translation>
    </message>
</context>
<context>
    <name>LoadImageFromFileOperation</name>
    <message>
        <source>Unable to open image</source>
        <translation>Nu s-a putut deschide imaginea</translation>
    </message>
    <message>
        <source>Unable to open image from path %1</source>
        <translation>Nu s-a putut deschide imaginea de la calea %1</translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <source>New</source>
        <translation>Nou</translation>
    </message>
    <message>
        <source>Delay in seconds between triggering
and capturing screenshot.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>s</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salvează</translation>
    </message>
    <message>
        <source>Save Screen Capture to file system</source>
        <translation>Salvează captura ecranului în sistemul de fișiere</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiază</translation>
    </message>
    <message>
        <source>Copy Screen Capture to clipboard</source>
        <translation>Copiază captura de ecran în clipboard</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Unelte</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Desfă</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Refă</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Decupează</translation>
    </message>
    <message>
        <source>Crop Screen Capture</source>
        <translation>Decupează captura de ecran</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Unsaved</source>
        <translation>Nesalvat</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Încarcă</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Tipărește</translation>
    </message>
    <message>
        <source>Opens printer dialog and provide option to print image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print Preview</source>
        <translation>Previzualizare tipărire</translation>
    </message>
    <message>
        <source>Opens Print Preview dialog where the image orientation can be changed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Scalează</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Termină</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configurări</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Despre</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Deschide</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editare</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>&amp;Opțiuni</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajutor</translation>
    </message>
    <message>
        <source>Add Watermark</source>
        <translation>Adaugă filigran</translation>
    </message>
    <message>
        <source>Add Watermark to captured image. Multiple watermarks can be added.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fișier</translation>
    </message>
    <message>
        <source>Unable to show image</source>
        <translation>Nu s-a putut arăta imaginea</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>Salvează ca…</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Lipește</translation>
    </message>
    <message>
        <source>Paste Embedded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Fixează</translation>
    </message>
    <message>
        <source>Pin screenshot to foreground in frameless window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No image provided but one was expected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>Copiază calea</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Deschide dosar</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Vizualizare</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Șterge</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Redenumește</translation>
    </message>
    <message>
        <source>Open Images</source>
        <translation>Deschide imagini</translation>
    </message>
    <message>
        <source>Show Docks</source>
        <translation>Arată andocări</translation>
    </message>
    <message>
        <source>Hide Docks</source>
        <translation>Ascunde andocări</translation>
    </message>
    <message>
        <source>Copy as data URI</source>
        <translation>Copiază datele ca URI</translation>
    </message>
    <message>
        <source>Open &amp;Recent</source>
        <translation>Deschide &amp;recent</translation>
    </message>
    <message>
        <source>Modify Canvas</source>
        <translation>Modifică canavaua</translation>
    </message>
    <message>
        <source>Upload triggerCapture to external source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy triggerCapture to system clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale Image</source>
        <translation>Scalează imaginea</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Rotește</translation>
    </message>
    <message>
        <source>Rotate Image</source>
        <translation>Rotește imaginea</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation type="unfinished">Acțiuni</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MultiCaptureHandler</name>
    <message>
        <source>Save</source>
        <translation>Salvează</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation>Salvează ca</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Deschide dosar</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiază</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>Copiază calea</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Șterge</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Redenumește</translation>
    </message>
</context>
<context>
    <name>NewCaptureNameProvider</name>
    <message>
        <source>Capture</source>
        <translation>Captură</translation>
    </message>
</context>
<context>
    <name>PinWindow</name>
    <message>
        <source>Close</source>
        <translation>Închide</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Închide celelalte</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Închide toate</translation>
    </message>
</context>
<context>
    <name>PinWindowHandler</name>
    <message>
        <source>Pin Window %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameOperation</name>
    <message>
        <source>Image Renamed</source>
        <translation>Imagine redenumită</translation>
    </message>
    <message>
        <source>Image Rename Failed</source>
        <translation>Redenumirea imaginii a eșuat</translation>
    </message>
    <message>
        <source>Rename image</source>
        <translation>Redenumește imaginea</translation>
    </message>
    <message>
        <source>New filename:</source>
        <translation>Denumire nouă:</translation>
    </message>
    <message>
        <source>Successfully renamed image to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to rename image to %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SaveOperation</name>
    <message>
        <source>Save As</source>
        <translation>Salvează ca</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Toate fișierele</translation>
    </message>
    <message>
        <source>Image Saved</source>
        <translation>Imagine salvată</translation>
    </message>
    <message>
        <source>Saving Image Failed</source>
        <translation>Salvarea imaginii a eșuat</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to save image to %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SaverSettings</name>
    <message>
        <source>Automatically save new captures to default location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prompt to save before discarding unsaved changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remember last Save Directory</source>
        <translation>Ține minte ultimul dosar de salvare</translation>
    </message>
    <message>
        <source>When enabled will overwrite the save directory stored in settings
with the latest save directory, for every save.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture save location and filename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Supported Formats are JPG, PNG and BMP. If no format provided, PNG will be used as default.
Filename can contain following wildcards:
- $Y, $M, $D for date, $h, $m, $s for time, or $T for time in hhmmss format.
- Multiple consecutive # for counter. #### will result in 0001, next capture would be 0002.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Răsfoiește</translation>
    </message>
    <message>
        <source>Saver Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture save location</source>
        <translation>Locul salvării capturilor</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Implicit</translation>
    </message>
    <message>
        <source>Factor</source>
        <translation>Factor</translation>
    </message>
    <message>
        <source>Save Quality</source>
        <translation>Calitate salvare</translation>
    </message>
    <message>
        <source>Specify 0 to obtain small compressed files, 100 for large uncompressed files.
Not all image formats support the full range, JPEG does.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScriptUploaderSettings</name>
    <message>
        <source>Copy script output to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Script:</source>
        <translation>Script:</translation>
    </message>
    <message>
        <source>Path to script that will be called for uploading. During upload the script will be called
with the path to a temporary png file as a single argument.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Răsfoiește</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Upload Script</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop when upload script writes to StdErr</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marks the upload as failed when script writes to StdErr.
Without this setting errors in the script will be unnoticed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filtru:</translation>
    </message>
    <message>
        <source>RegEx Expression. Only copy to clipboard what matches the RegEx Expression.
When omitted, everything is copied.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Configurări</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Bine</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Renunță</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>Acaparator de imagini</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Încărcător Imgur</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Aplicație</translation>
    </message>
    <message>
        <source>Annotator</source>
        <translation>Adnotator</translation>
    </message>
    <message>
        <source>HotKeys</source>
        <translation>Scurtături</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>Încărcător</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stickers</source>
        <translation>Autocolante</translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation type="unfinished">Zona tăieturii</translation>
    </message>
    <message>
        <source>Tray Icon</source>
        <translation>Pictogramă în tavă</translation>
    </message>
    <message>
        <source>Watermark</source>
        <translation>Filigran</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Acțiuni</translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SnippingAreaResizerInfoText</name>
    <message>
        <source>Resize selected rect using the handles or move it by dragging the selection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use arrow keys to move the selection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use arrow keys while pressing CTRL to move top left handle.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Confirm selection by pressing ENTER/RETURN or abort by pressing ESC.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation>Acest mesaj poate fi dezactivat în configurări.</translation>
    </message>
</context>
<context>
    <name>SnippingAreaSelectorInfoText</name>
    <message>
        <source>Click and Drag to select a rectangular area or press ESC to quit.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hold CTRL pressed to resize selection after selecting.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hold CTRL pressed to prevent resizing after selecting.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Operation will be canceled after 60 sec when no selection made.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation>Acest mesaj poate fi dezactivat în configurări.</translation>
    </message>
</context>
<context>
    <name>SnippingAreaSettings</name>
    <message>
        <source>Freeze Image while snipping</source>
        <translation>Îngheață imaginea la tăiere</translation>
    </message>
    <message>
        <source>When enabled will freeze the background while
selecting a rectangular region. It also changes
the behavior of delayed screenshots, with this
option enabled the delay happens before the
snipping area is shown and with the option disabled
the delay happens after the snipping area is shown.
This feature is always disabled for Wayland and always
enabled for MacOs.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show magnifying glass on snipping area</source>
        <translation>Arată lupa pe zona tăieturii</translation>
    </message>
    <message>
        <source>Show a magnifying glass which zooms into
the background image. This option only works
with &apos;Freeze Image while snipping&apos; enabled.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Snipping Area rulers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Horizontal and vertical lines going from
desktop edges to cursor on snipping area.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Snipping Area position and size info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When left mouse button is not pressed the position
is shown, when the mouse button is pressed,
the size of the select area is shown left
and above from the captured area.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow resizing rect area selection by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled will, after selecting a rect
area, allow resizing the selection. When
done resizing the selection can be confirmed
by pressing return.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Snipping Area info text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area cursor color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sets the color of the snipping area cursor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area cursor thickness</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sets the thickness of the snipping area cursor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation>Zona tăieturii</translation>
    </message>
    <message>
        <source>Snipping Area adorner color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sets the color of all adorner elements
on the snipping area.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area Transparency</source>
        <translation>Transparența zonei tăieturii</translation>
    </message>
    <message>
        <source>Alpha for not selected region on snipping area.
Smaller number is more transparent.</source>
        <translation>Alfa pentru regiunea nealeasă în zona tăieturii.
Numerele mai mici sunt mai transparente.</translation>
    </message>
</context>
<context>
    <name>StickerSettings</name>
    <message>
        <source>Up</source>
        <translation>Sus</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Jos</translation>
    </message>
    <message>
        <source>Use Default Stickers</source>
        <translation>Folosește autocolante implicite</translation>
    </message>
    <message>
        <source>Sticker Settings</source>
        <translation>Configurări autocolante</translation>
    </message>
    <message>
        <source>Vector Image Files (*.svg)</source>
        <translation>Fișiere cu imagini vectoriale (*.svg)</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Adaugă</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Elimină</translation>
    </message>
    <message>
        <source>Add Stickers</source>
        <translation>Adaugă autocolante</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <source>Show Editor</source>
        <translation>Arată redactorul</translation>
    </message>
</context>
<context>
    <name>TrayIconSettings</name>
    <message>
        <source>Use Tray Icon</source>
        <translation>Folosește pictogramă în tavă</translation>
    </message>
    <message>
        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
Change requires restart.</source>
        <translation>Când e activată, va adăuga o pictogramă în tava de sistem dacă gestionarul de ferestre o susține.
Modificarea necesită repornire.</translation>
    </message>
    <message>
        <source>Minimize to Tray</source>
        <translation>Minimizează în tavă</translation>
    </message>
    <message>
        <source>Start Minimized to Tray</source>
        <translation>Pornește minimizat în tavă</translation>
    </message>
    <message>
        <source>Close to Tray</source>
        <translation>Închide în tavă</translation>
    </message>
    <message>
        <source>Show Editor</source>
        <translation>Arată redactorul</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Captură</translation>
    </message>
    <message>
        <source>Default Tray Icon action</source>
        <translation>Acțiune implicită pentru pictograma din tavă</translation>
    </message>
    <message>
        <source>Default Action that is triggered by left clicking the tray icon.</source>
        <translation>Acțiune implicită declanșată la clic stâng pe pictograma din tavă.</translation>
    </message>
    <message>
        <source>Tray Icon Settings</source>
        <translation>Configurări pictogramă în tavă</translation>
    </message>
    <message>
        <source>Use platform specific notification service</source>
        <translation>Folosește serviciu de notificare specific platformei</translation>
    </message>
    <message>
        <source>When enabled will use try to use platform specific notification
service when such exists. Change requires restart to take effect.</source>
        <translation>Când e activat, se va încerca folosirea serviciului de notificare specific
platformei, dacă există. Modificarea necesită o repornire pentru a intra în vigoare.</translation>
    </message>
    <message>
        <source>Display Tray Icon notifications</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdateWatermarkOperation</name>
    <message>
        <source>Select Image</source>
        <translation>Alege imaginea</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UploadOperation</name>
    <message>
        <source>Upload Script Required</source>
        <translation>Script de încărcare necesar</translation>
    </message>
    <message>
        <source>Please add an upload script via Options &gt; Settings &gt; Upload Script</source>
        <translation>Adăugați un script de încărcare în Opțiuni &gt; Configurări &gt; Script de încărcare</translation>
    </message>
    <message>
        <source>Capture Upload</source>
        <translation>Încărcare captură</translation>
    </message>
    <message>
        <source>You are about to upload the image to an external destination, do you want to proceed?</source>
        <translation>Sunteți pe cale să încărcați imaginea pe o destinație externă, doriți să continuați?</translation>
    </message>
</context>
<context>
    <name>UploaderSettings</name>
    <message>
        <source>Ask for confirmation before uploading</source>
        <translation>Cere confirmare înainte de a încărca</translation>
    </message>
    <message>
        <source>Uploader Type:</source>
        <translation>Tip încărcător:</translation>
    </message>
    <message>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <source>Script</source>
        <translation>Script</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>Încărcător</translation>
    </message>
    <message>
        <source>FTP</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VersionTab</name>
    <message>
        <source>Version</source>
        <translation>Versiune</translation>
    </message>
    <message>
        <source>Build</source>
        <translation>Construire</translation>
    </message>
    <message>
        <source>Using:</source>
        <translation>Folosind:</translation>
    </message>
</context>
<context>
    <name>WatermarkSettings</name>
    <message>
        <source>Watermark Image</source>
        <translation>Imagine filigran</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Actualizează</translation>
    </message>
    <message>
        <source>Rotate Watermark</source>
        <translation>Rotește filigranul</translation>
    </message>
    <message>
        <source>When enabled, Watermark will be added with a rotation of 45°</source>
        <translation>La activare, filigranul va fi adăugat cu rotație de 45°</translation>
    </message>
    <message>
        <source>Watermark Settings</source>
        <translation>Configurări filigran</translation>
    </message>
</context>
</TS>
